Spelling fix

Francois Gouget fgouget at free.fr
Thu May 11 17:24:56 CDT 2006


This patch fixes the spelling of 'Transferring', including in the 
TransferingDialogBox function name, which is why I have set it apart. 
Note that since this is a private function so there is no reason to keep 
the wrong spelling.

Changelog:

  * dlls/gphoto2.ds/ds_ctrl.c
    dlls/gphoto2.ds/ds_image.c
    dlls/gphoto2.ds/gphoto2_i.h
    dlls/gphoto2.ds/ui.c

    Francois Gouget <fgouget at free.fr>
    Fix spelling of TransferingDialogBox().


-- 
Francois Gouget <fgouget at free.fr>              http://fgouget.free.fr/
  The greatest programming project of all took six days; on the seventh day the
   programmer rested. We've been trying to debug the *&^%$#@ thing ever since.
                       Moral: design before you implement.
-------------- next part --------------
Index: dlls/gphoto2.ds/ds_image.c
===================================================================
RCS file: /home/wine/wine/dlls/gphoto2.ds/ds_image.c,v
retrieving revision 1.1
diff -u -p -r1.1 ds_image.c
--- dlls/gphoto2.ds/ds_image.c	8 May 2006 20:40:09 -0000	1.1
+++ dlls/gphoto2.ds/ds_image.c	11 May 2006 20:57:48 -0000
@@ -316,8 +316,8 @@ TW_UINT16 GPHOTO2_ImageMemXferGet (pTW_I
 	}
 
     if (!activeDS.progressWnd)
-        activeDS.progressWnd = TransferingDialogBox(NULL,0);
-    TransferingDialogBox(activeDS.progressWnd,0);
+        activeDS.progressWnd = TransferringDialogBox(NULL,0);
+    TransferringDialogBox(activeDS.progressWnd,0);
 
         activeDS.currentState = 7;
     } else {
@@ -355,7 +355,7 @@ TW_UINT16 GPHOTO2_ImageMemXferGet (pTW_I
     pImageMemXfer->Columns	= activeDS.jd.output_width; /* we do whole strips */
     pImageMemXfer->BytesWritten = curoff;
 
-    TransferingDialogBox(activeDS.progressWnd,0);
+    TransferringDialogBox(activeDS.progressWnd,0);
 
     if (activeDS.jd.output_scanline == activeDS.jd.output_height) {
         pjpeg_finish_decompress(&activeDS.jd);
@@ -364,7 +364,7 @@ TW_UINT16 GPHOTO2_ImageMemXferGet (pTW_I
 	activeDS.file = NULL;
 	TRACE("xfer is done!\n");
 
-	/*TransferingDialogBox(activeDS.progressWnd, -1);*/
+	/*TransferringDialogBox(activeDS.progressWnd, -1);*/
 	twRC = TWRC_XFERDONE;
     }
     activeDS.twCC = TWRC_SUCCESS;
Index: dlls/gphoto2.ds/gphoto2_i.h
===================================================================
RCS file: /home/wine/wine/dlls/gphoto2.ds/gphoto2_i.h,v
retrieving revision 1.1
diff -u -p -r1.1 gphoto2_i.h
--- dlls/gphoto2.ds/gphoto2_i.h	8 May 2006 20:40:09 -0000	1.1
+++ dlls/gphoto2.ds/gphoto2_i.h	11 May 2006 20:57:48 -0000
@@ -247,7 +247,7 @@ TW_UINT16 GPHOTO2_RGBResponseSet
 
 /* UI function */
 BOOL DoCameraUI();
-HWND TransferingDialogBox(HWND dialog, DWORD progress);
+HWND TransferringDialogBox(HWND dialog, DWORD progress);
 
 #ifdef HAVE_GPHOTO2
 /* Helper function for GUI */
Index: dlls/gphoto2.ds/ui.c
===================================================================
RCS file: /home/wine/wine/dlls/gphoto2.ds/ui.c,v
retrieving revision 1.1
diff -u -p -r1.1 ui.c
--- dlls/gphoto2.ds/ui.c	8 May 2006 20:40:09 -0000	1.1
+++ dlls/gphoto2.ds/ui.c	11 May 2006 20:57:48 -0000
@@ -238,7 +238,7 @@ static INT_PTR CALLBACK ProgressProc(HWN
 	    return FALSE;
 }   
 
-HWND TransferingDialogBox(HWND dialog, DWORD progress)
+HWND TransferringDialogBox(HWND dialog, DWORD progress)
 {
 	if (!dialog)
 		dialog = CreateDialogW(GPHOTO2_instance,


More information about the wine-patches mailing list
Index: dlls/gphoto2.ds/ds_ctrl.c
===================================================================
RCS file: /home/wine/wine/dlls/gphoto2.ds/ds_ctrl.c,v
retrieving revision 1.1
diff -u -p -r1.1 ds_ctrl.c
--- dlls/gphoto2.ds/ds_ctrl.c	8 May 2006 20:40:09 -0000	1.1
+++ dlls/gphoto2.ds/ds_ctrl.c	11 May 2006 20:57:48 -0000
@@ -363,8 +363,8 @@ TW_UINT16 GPHOTO2_PendingXfersEndXfer (p
         activeDS.currentState = 5;
         /* Notify the application that it can close the data source */
         activeDS.pendingEvent.TWMessage = MSG_CLOSEDSREQ;
-        /* close any Transfering dialog */
-        TransferingDialogBox(activeDS.progressWnd,-1);
+        /* close any Transferring dialog */
+        TransferringDialogBox(activeDS.progressWnd,-1);
         activeDS.progressWnd = 0;
     }
     activeDS.twCC = TWCC_SUCCESS;